==> libgphoto2-2.5.5.1.tar.bz2: libgphoto2-api.html/gphoto2-camera_8h.js <==
var gphoto2_camera_8h =
[
    [ "CameraText", "structCameraText.html", "structCameraText" ],
    [ "CameraFilePath", "structCameraFilePath.html", "structCameraFilePath" ],
    [ "_CameraFunctions", "struct__CameraFunctions.html", "struct__CameraFunctions" ],
    [ "_Camera", "struct__Camera.html", "struct__Camera" ],
    [ "Camera", "gphoto2-camera_8h.html#a5ef187a092edd693b3d01ad8304728fb", null ],
    [ "CameraAboutFunc", "gphoto2-camera_8h.html#a59488e3dd0ddcef77a7384eee37fe067", null ],
    [ "CameraCaptureFunc", "gphoto2-camera_8h.html#a4208baa7fd92b29a16d26a1358c26601", null ],
    [ "CameraCapturePreviewFunc", "gphoto2-camera_8h.html#af409b026902d6f0bed4f8b785ea78925", null ],
    [ "CameraExitFunc", "gphoto2-camera_8h.html#acfcb658bea428bc381411be6c198b65c", null ],
    [ "CameraFunctions", "gphoto2-camera_8h.html#a298fe44a034ee548ba07d29a943c8256", null ],
    [ "CameraGetConfigFunc", "gphoto2-camera_8h.html#aacf58fa53f052c961690a93ddd3125c1", null ],
    [ "CameraManualFunc", "gphoto2-camera_8h.html#ae602b658b04d076214fea3ea79336b7b", null ],
    [ "CameraPrePostFunc", "gphoto2-camera_8h.html#a959d563c5d9a1352121753dd06fcad0d", null ],
    [ "CameraPrivateCore", "gphoto2-camera_8h.html#a2ca795a13c68fd59a19b2eb461e83a00", null ],
    [ "CameraPrivateLibrary", "gphoto2-camera_8h.html#ab7d4d1356a21b031b0208b83551009d5", null ],
    [ "CameraSetConfigFunc", "gphoto2-camera_8h.html#abd91bd0b63b342ad9bb963ccc8552e56", null ],
    [ "CameraSummaryFunc", "gphoto2-camera_8h.html#ae60fbd21e979273a36f05e651350e616", null ],
    [ "CameraTimeoutFunc", "gphoto2-camera_8h.html#a20c66b23053b59b6897f722da15a6170", null ],
    [ "CameraTimeoutStartFunc", "gphoto2-camera_8h.html#ad8a93c18bf8fdb15100bc3b00dcfd19d", null ],
    [ "CameraTimeoutStopFunc", "gphoto2-camera_8h.html#a7217e0e6352b735eb729d55b94581f41", null ],
    [ "CameraTriggerCaptureFunc", "gphoto2-camera_8h.html#a77b1b8be20f036c3d8dc3aba7278a906", null ],
    [ "CameraWaitForEvent", "gphoto2-camera_8h.html#ab64667d4bf9ca111e71469d31b8d5576", null ],
    [ "CameraCaptureType", "gphoto2-camera_8h.html#a6a66768c14ce761d6810f64572c79ec1", [
      [ "GP_CAPTURE_IMAGE", "gphoto2-camera_8h.html#a6a66768c14ce761d6810f64572c79ec1a4e6ca859490742a8435d04223c2a0056", null ],
      [ "GP_CAPTURE_MOVIE", "gphoto2-camera_8h.html#a6a66768c14ce761d6810f64572c79ec1afa8c68bfa3fa365ad562ca6929e6cee7", null ],
      [ "GP_CAPTURE_SOUND", "gphoto2-camera_8h.html#a6a66768c14ce761d6810f64572c79ec1ae2166855f1a96d61dc4da6cef03bce4d", null ]
    ] ],
    [ "CameraEventType", "gphoto2-camera_8h.html#a438ab2ac60ad5d5ced30e4201476800b", [
      [ "GP_EVENT_UNKNOWN", "gphoto2-camera_8h.html#a438ab2ac60ad5d5ced30e4201476800bac818979d0da4b73b7de8e0ad0cffcf2f", null ],
      [ "GP_EVENT_TIMEOUT", "gphoto2-camera_8h.html#a438ab2ac60ad5d5ced30e4201476800ba6201d8e02b4a46ee7c67d7478b8b7658", null ],
      [ "GP_EVENT_FILE_ADDED", "gphoto2-camera_8h.html#a438ab2ac60ad5d5ced30e4201476800ba0575ebbc9e85ac5cd424ef20a77b7162", null ],
      [ "GP_EVENT_FOLDER_ADDED", "gphoto2-camera_8h.html#a438ab2ac60ad5d5ced30e4201476800ba0f9561e9d66ea77a89eb472d75ba11e2", null ],
      [ "GP_EVENT_CAPTURE_COMPLETE", "gphoto2-camera_8h.html#a438ab2ac60ad5d5ced30e4201476800bafd65c3c57e22b937ad1d4a2663ef4070", null ]
    ] ],
    [ "gp_camera_autodetect", "gphoto2-camera_8h.html#ae7b6050bb4bc7a697f9e07253c27710f", null ],
    [ "gp_camera_capture", "gphoto2-camera_8h.html#a8fa6903e3bf0ab26edc4e915512aa44f", null ],
    [ "gp_camera_capture_preview", "gphoto2-camera_8h.html#accaa70d614800dac941e543187c9712d", null ],
    [ "gp_camera_exit", "gphoto2-camera_8h.html#a6f19c4ea385641fb972e779badf48ae1", null ],
    [ "gp_camera_file_delete", "gphoto2-camera_8h.html#a456172175ee1829ef172ee9c747e850d", null ],
    [ "gp_camera_file_get", "gphoto2-camera_8h.html#a262b1bc840d62b12605e3acc543f714d", null ],
    [ "gp_camera_file_get_info", "gphoto2-camera_8h.html#adda54321b1947b711d345936041f80c7", null ],
    [ "gp_camera_file_read", "gphoto2-camera_8h.html#a1c1ad4e0cc48fec22aaddbba147975c8", null ],
    [ "gp_camera_file_set_info", "gphoto2-camera_8h.html#a1a66b26a0456f3d265051c4018f67208", null ],
    [ "gp_camera_folder_delete_all", "gphoto2-camera_8h.html#a0c61c3d62a6bb6daecbadbffa06cf3fb", null ],
    [ "gp_camera_folder_list_files", "gphoto2-camera_8h.html#a0cdf2043359617d5132665c36fc557d0", null ],
    [ "gp_camera_folder_list_folders", "gphoto2-camera_8h.html#a7dc2b5ed66b61b881caf7436cb05ded0", null ],
    [ "gp_camera_folder_make_dir", "gphoto2-camera_8h.html#a6b6669216aeae67304649edd42db605d", null ],
    [ "gp_camera_folder_put_file", "gphoto2-camera_8h.html#aa3dd64d491735a55bcab15d41b9113c3", null ],
    [ "gp_camera_folder_remove_dir", "gphoto2-camera_8h.html#a11f3855eef4f009701b008908fc78608", null ],
    [ "gp_camera_free", "gphoto2-camera_8h.html#a78ae1a19cc0fb4d94026f82497381124", null ],
    [ "gp_camera_get_abilities", "gphoto2-camera_8h.html#a240f8cc35944b01cce71609c265fda3a", null ],
    [ "gp_camera_get_about", "gphoto2-camera_8h.html#a0a46cbd79e1a634acebec4380cee6c5b", null ],
    [ "gp_camera_get_config", "gphoto2-camera_8h.html#ae87f24abbc6ee895867331c64e6986cf", null ],
    [ "gp_camera_get_manual", "gphoto2-camera_8h.html#a32cfd1eaec837dd43676eb211fa68cdb", null ],
    [ "gp_camera_get_port_info", "gphoto2-camera_8h.html#a969c10fd16501f62f0e3a276d237764a", null ],
    [ "gp_camera_get_port_speed", "gphoto2-camera_8h.html#a068405c418270c7c63ab9fdc3c0ae620", null ],
    [ "gp_camera_get_storageinfo", "gphoto2-camera_8h.html#aa22be0b9b3018082174d0f7c8ecd2e26", null ],
    [ "gp_camera_get_summary", "gphoto2-camera_8h.html#a7a2b16620e8dcd0efbd6f767188d9162", null ],
    [ "gp_camera_init", "gphoto2-camera_8h.html#ab0e3da4a22b7b71ec36e58157c868a9e", null ],
    [ "gp_camera_new", "gphoto2-camera_8h.html#ad89d6ee1c35f5ee399e89ecaeac6bd61", null ],
    [ "gp_camera_ref", "gphoto2-camera_8h.html#a449781f840d1a82e56f424d33371c511", null ],
    [ "gp_camera_set_abilities", "gphoto2-camera_8h.html#a95f595a6d9bfe68d99419a0087363f89", null ],
    [ "gp_camera_set_config", "gphoto2-camera_8h.html#a0b289e071be43bfeb6e65757cc274dbf", null ],
    [ "gp_camera_set_port_info", "gphoto2-camera_8h.html#a87bb8878064d7c4a98f1be7cedf7fd3c", null ],
    [ "gp_camera_set_port_speed", "gphoto2-camera_8h.html#a0fc2c594397f144a134074757e9dfab1", null ],
    [ "gp_camera_set_timeout_funcs", "gphoto2-camera_8h.html#af2e448cda5a2a1637d497fec7b89c44f", null ],
    [ "gp_camera_start_timeout", "gphoto2-camera_8h.html#a640b436ef19db8154283cc3044fb1d0a", null ],
    [ "gp_camera_stop_timeout", "gphoto2-camera_8h.html#a6d95c83814161ccd8f4cc1e86233c9d4", null ],
    [ "gp_camera_trigger_capture", "gphoto2-camera_8h.html#a5d5649f8c672a52800d0723bf29f33fa", null ],
    [ "gp_camera_unref", "gphoto2-camera_8h.html#a6027cb54859c035ce943cf1c3e06121a", null ],
    [ "gp_camera_wait_for_event", "gphoto2-camera_8h.html#a6a3aa30acd4bbe74087ce0fbcb9ea3a9", null ]
];

==> libgphoto2_2.5.16.orig.tar.bz2: libgphoto2-api.html/gphoto2-camera_8h.js <==
var gphoto2_camera_8h =
[
    [ "CameraText", "structCameraText.html", "structCameraText" ],
    [ "CameraFilePath", "structCameraFilePath.html", "structCameraFilePath" ],
    [ "_CameraFunctions", "struct__CameraFunctions.html", "struct__CameraFunctions" ],
    [ "_Camera", "struct__Camera.html", "struct__Camera" ],
    [ "Camera", "gphoto2-camera_8h.html#a5ef187a092edd693b3d01ad8304728fb", null ],
    [ "CameraAboutFunc", "gphoto2-camera_8h.html#ac97991bc04586bd093569b1b00d07821", null ],
    [ "CameraCaptureFunc", "gphoto2-camera_8h.html#aae2a7f4fc07d99b4524fa29f76975b11", null ],
    [ "CameraCapturePreviewFunc", "gphoto2-camera_8h.html#ae23c3eeb280ab6274ca5ac15db31c54a", null ],
    [ "CameraExitFunc", "gphoto2-camera_8h.html#ac3484d913060abf885b6bfd016320f80", null ],
    [ "CameraFunctions", "gphoto2-camera_8h.html#a298fe44a034ee548ba07d29a943c8256", null ],
    [ "CameraGetConfigFunc", "gphoto2-camera_8h.html#aaf28826f8251bfde0f1cbc07fae1bf50", null ],
    [ "CameraGetSingleConfigFunc", "gphoto2-camera_8h.html#ad1c8f7fc0c347f7eb3d443a06ab10370", null ],
    [ "CameraListConfigFunc", "gphoto2-camera_8h.html#ae3feebdc2059efb01336ae6ad9583acc", null ],
    [ "CameraManualFunc", "gphoto2-camera_8h.html#adb3e8a4b8b179b6319fc90b6d2105fb1", null ],
    [ "CameraPrePostFunc", "gphoto2-camera_8h.html#a40a20fdc154b0631cbd3a0a95d1ae165", null ],
    [ "CameraPrivateCore", "gphoto2-camera_8h.html#a2ca795a13c68fd59a19b2eb461e83a00", null ],
    [ "CameraPrivateLibrary", "gphoto2-camera_8h.html#ab7d4d1356a21b031b0208b83551009d5", null ],
    [ "CameraSetConfigFunc", "gphoto2-camera_8h.html#a26351cb024be661dd0cb7e48afd8bc8a", null ],
    [ "CameraSetSingleConfigFunc", "gphoto2-camera_8h.html#a2ca051bcc451341fd0c93b64f521bfaf", null ],
    [ "CameraSummaryFunc", "gphoto2-camera_8h.html#a26facb6ff3b8a39d1968fa23d950f9de", null ],
    [ "CameraTimeoutFunc", "gphoto2-camera_8h.html#ad3b42d26bfbfe0fb0b9671c84c50f138", null ],
    [ "CameraTimeoutStartFunc", "gphoto2-camera_8h.html#a6c72255946125f3aec9f673080f401d3", null ],
    [ "CameraTimeoutStopFunc", "gphoto2-camera_8h.html#aa93f252a9f1957bd563e759bc7debac2", null ],
    [ "CameraTriggerCaptureFunc", "gphoto2-camera_8h.html#a2b4c42276b047ed5b33ef5646db8becc", null ],
    [ "CameraWaitForEvent", "gphoto2-camera_8h.html#aac1b7a2a855f989bdbdd255fdf04a46c", null ],
    [ "CameraCaptureType", "gphoto2-camera_8h.html#a6a66768c14ce761d6810f64572c79ec1", [
      [ "GP_CAPTURE_IMAGE", "gphoto2-camera_8h.html#a6a66768c14ce761d6810f64572c79ec1a4e6ca859490742a8435d04223c2a0056", null ],
      [ "GP_CAPTURE_MOVIE", "gphoto2-camera_8h.html#a6a66768c14ce761d6810f64572c79ec1afa8c68bfa3fa365ad562ca6929e6cee7", null ],
      [ "GP_CAPTURE_SOUND", "gphoto2-camera_8h.html#a6a66768c14ce761d6810f64572c79ec1ae2166855f1a96d61dc4da6cef03bce4d", null ]
    ] ],
    [ "CameraEventType", "gphoto2-camera_8h.html#a438ab2ac60ad5d5ced30e4201476800b", [
      [ "GP_EVENT_UNKNOWN", "gphoto2-camera_8h.html#a438ab2ac60ad5d5ced30e4201476800bac818979d0da4b73b7de8e0ad0cffcf2f", null ],
      [ "GP_EVENT_TIMEOUT", "gphoto2-camera_8h.html#a438ab2ac60ad5d5ced30e4201476800ba6201d8e02b4a46ee7c67d7478b8b7658", null ],
      [ "GP_EVENT_FILE_ADDED", "gphoto2-camera_8h.html#a438ab2ac60ad5d5ced30e4201476800ba0575ebbc9e85ac5cd424ef20a77b7162", null ],
      [ "GP_EVENT_FOLDER_ADDED", "gphoto2-camera_8h.html#a438ab2ac60ad5d5ced30e4201476800ba0f9561e9d66ea77a89eb472d75ba11e2", null ],
      [ "GP_EVENT_CAPTURE_COMPLETE", "gphoto2-camera_8h.html#a438ab2ac60ad5d5ced30e4201476800bafd65c3c57e22b937ad1d4a2663ef4070", null ]
    ] ],
    [ "gp_camera_autodetect", "gphoto2-camera_8h.html#ae7b6050bb4bc7a697f9e07253c27710f", null ],
    [ "gp_camera_capture", "gphoto2-camera_8h.html#a8fa6903e3bf0ab26edc4e915512aa44f", null ],
    [ "gp_camera_capture_preview", "gphoto2-camera_8h.html#accaa70d614800dac941e543187c9712d", null ],
    [ "gp_camera_exit", "gphoto2-camera_8h.html#a6f19c4ea385641fb972e779badf48ae1", null ],
    [ "gp_camera_file_delete", "gphoto2-camera_8h.html#a456172175ee1829ef172ee9c747e850d", null ],
    [ "gp_camera_file_get", "gphoto2-camera_8h.html#a262b1bc840d62b12605e3acc543f714d", null ],
    [ "gp_camera_file_get_info", "gphoto2-camera_8h.html#adda54321b1947b711d345936041f80c7", null ],
    [ "gp_camera_file_read", "gphoto2-camera_8h.html#a1c1ad4e0cc48fec22aaddbba147975c8", null ],
    [ "gp_camera_file_set_info", "gphoto2-camera_8h.html#a1a66b26a0456f3d265051c4018f67208", null ],
    [ "gp_camera_folder_delete_all", "gphoto2-camera_8h.html#a0c61c3d62a6bb6daecbadbffa06cf3fb", null ],
    [ "gp_camera_folder_list_files", "gphoto2-camera_8h.html#a0cdf2043359617d5132665c36fc557d0", null ],
    [ "gp_camera_folder_list_folders", "gphoto2-camera_8h.html#a7dc2b5ed66b61b881caf7436cb05ded0", null ],
    [ "gp_camera_folder_make_dir", "gphoto2-camera_8h.html#a6b6669216aeae67304649edd42db605d", null ],
    [ "gp_camera_folder_put_file", "gphoto2-camera_8h.html#aa3dd64d491735a55bcab15d41b9113c3", null ],
    [ "gp_camera_folder_remove_dir", "gphoto2-camera_8h.html#a11f3855eef4f009701b008908fc78608", null ],
    [ "gp_camera_free", "gphoto2-camera_8h.html#a78ae1a19cc0fb4d94026f82497381124", null ],
    [ "gp_camera_get_abilities", "gphoto2-camera_8h.html#a240f8cc35944b01cce71609c265fda3a", null ],
    [ "gp_camera_get_about", "gphoto2-camera_8h.html#a0a46cbd79e1a634acebec4380cee6c5b", null ],
    [ "gp_camera_get_config", "gphoto2-camera_8h.html#ae87f24abbc6ee895867331c64e6986cf", null ],
    [ "gp_camera_get_manual", "gphoto2-camera_8h.html#a32cfd1eaec837dd43676eb211fa68cdb", null ],
    [ "gp_camera_get_port_info", "gphoto2-camera_8h.html#a969c10fd16501f62f0e3a276d237764a", null ],
    [ "gp_camera_get_port_speed", "gphoto2-camera_8h.html#a068405c418270c7c63ab9fdc3c0ae620", null ],
    [ "gp_camera_get_single_config", "gphoto2-camera_8h.html#abf808fe8f9c7b0dbf9f9c4b6d5aef4b2", null ],
    [ "gp_camera_get_storageinfo", "gphoto2-camera_8h.html#aa22be0b9b3018082174d0f7c8ecd2e26", null ],
    [ "gp_camera_get_summary", "gphoto2-camera_8h.html#a7a2b16620e8dcd0efbd6f767188d9162", null ],
    [ "gp_camera_init", "gphoto2-camera_8h.html#ab0e3da4a22b7b71ec36e58157c868a9e", null ],
    [ "gp_camera_list_config", "gphoto2-camera_8h.html#a01d8d222d4b7f090f678080b8ce9998e", null ],
    [ "gp_camera_new", "gphoto2-camera_8h.html#ad89d6ee1c35f5ee399e89ecaeac6bd61", null ],
    [ "gp_camera_ref", "gphoto2-camera_8h.html#a449781f840d1a82e56f424d33371c511", null ],
    [ "gp_camera_set_abilities", "gphoto2-camera_8h.html#a95f595a6d9bfe68d99419a0087363f89", null ],
    [ "gp_camera_set_config", "gphoto2-camera_8h.html#a0b289e071be43bfeb6e65757cc274dbf", null ],
    [ "gp_camera_set_port_info", "gphoto2-camera_8h.html#a87bb8878064d7c4a98f1be7cedf7fd3c", null ],
    [ "gp_camera_set_port_speed", "gphoto2-camera_8h.html#a0fc2c594397f144a134074757e9dfab1", null ],
    [ "gp_camera_set_single_config", "gphoto2-camera_8h.html#ae231c37c434852418e308cda85f262e9", null ],
    [ "gp_camera_set_timeout_funcs", "gphoto2-camera_8h.html#af2e448cda5a2a1637d497fec7b89c44f", null ],
    [ "gp_camera_start_timeout", "gphoto2-camera_8h.html#a640b436ef19db8154283cc3044fb1d0a", null ],
    [ "gp_camera_stop_timeout", "gphoto2-camera_8h.html#a6d95c83814161ccd8f4cc1e86233c9d4", null ],
    [ "gp_camera_trigger_capture", "gphoto2-camera_8h.html#a5d5649f8c672a52800d0723bf29f33fa", null ],
    [ "gp_camera_unref", "gphoto2-camera_8h.html#a6027cb54859c035ce943cf1c3e06121a", null ],
    [ "gp_camera_wait_for_event", "gphoto2-camera_8h.html#a6a3aa30acd4bbe74087ce0fbcb9ea3a9", null ]
];
